# coding: utf-8


"""
    sdtables - Load table data from various sources
    into python dictionary structures

    cunningr - 2020

    Requires:
     - openpyxl >= 2.6.2 <= 3.0.3
     - jsonschema


"""

__version__ = "1.0.3"

from sdtables.xlTables import *
